Class: Aws::MarketplaceAgreement::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MarketplaceAgreement::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-marketplaceagreement/client.rb,
sig/client.rbs
Overview
An API client for MarketplaceAgreement. To construct a client, you need to configure a :region and :credentials.
client = Aws::MarketplaceAgreement::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptAgreementCancellationRequestResponseSuccess, _AcceptAgreementPaymentRequestResponseSuccess, _AcceptAgreementRequestResponseSuccess, _BatchCreateBillingAdjustmentRequestResponseSuccess, _CancelAgreementCancellationRequestResponseSuccess, _CancelAgreementPaymentRequestResponseSuccess, _CancelAgreementResponseSuccess, _CreateAgreementRequestResponseSuccess, _DescribeAgreementResponseSuccess, _GetAgreementCancellationRequestResponseSuccess, _GetAgreementEntitlementsResponseSuccess, _GetAgreementPaymentRequestResponseSuccess, _GetAgreementTermsResponseSuccess, _GetBillingAdjustmentRequestResponseSuccess, _ListAgreementCancellationRequestsResponseSuccess, _ListAgreementChargesResponseSuccess, _ListAgreementInvoiceLineItemsResponseSuccess, _ListAgreementPaymentRequestsResponseSuccess, _ListBillingAdjustmentRequestsResponseSuccess, _RejectAgreementCancellationRequestResponseSuccess, _RejectAgreementPaymentRequestResponseSuccess, _SearchAgreementsResponseSuccess, _SendAgreementCancellationRequestResponseSuccess, _SendAgreementPaymentRequestResponseSuccess, _UpdatePurchaseOrdersResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_agreement_cancellation_request(params = {}) ⇒ Types::AcceptAgreementCancellationRequestOutput
Allows buyers (acceptors) to accept a cancellation request that is in
PENDING_APPROVALstatus. -
#accept_agreement_payment_request(params = {}) ⇒ Types::AcceptAgreementPaymentRequestOutput
Allows buyers (acceptors) to accept a payment request that is in
PENDING_APPROVALstatus. -
#accept_agreement_request(params = {}) ⇒ Types::AcceptAgreementRequestOutput
Accepts an agreement request to finalize the agreement.
-
#batch_create_billing_adjustment_request(params = {}) ⇒ Types::BatchCreateBillingAdjustmentRequestOutput
Allows sellers (proposers) to submit billing adjustment requests for one or more invoices within an agreement.
-
#cancel_agreement(params = {}) ⇒ Struct
Allows an acceptor to cancel an active agreement.
-
#cancel_agreement_cancellation_request(params = {}) ⇒ Types::CancelAgreementCancellationRequestOutput
Allows sellers (proposers) to withdraw an existing agreement cancellation request that is in a pending state.
-
#cancel_agreement_payment_request(params = {}) ⇒ Types::CancelAgreementPaymentRequestOutput
Allows sellers (proposers) to cancel a payment request that is in
PENDING_APPROVALstatus. -
#create_agreement_request(params = {}) ⇒ Types::CreateAgreementRequestOutput
Creates an agreement request that acts as a quote for the terms you want to accept.
-
#describe_agreement(params = {}) ⇒ Types::DescribeAgreementOutput
Provides details about an agreement, such as the proposer, acceptor, start date, and end date.
-
#get_agreement_cancellation_request(params = {}) ⇒ Types::GetAgreementCancellationRequestOutput
Retrieves detailed information about a specific agreement cancellation request.
-
#get_agreement_entitlements(params = {}) ⇒ Types::GetAgreementEntitlementsOutput
Obtains details about the entitlements of an agreement.
-
#get_agreement_payment_request(params = {}) ⇒ Types::GetAgreementPaymentRequestOutput
Retrieves detailed information about a specific payment request.
-
#get_agreement_terms(params = {}) ⇒ Types::GetAgreementTermsOutput
Obtains details about the terms in an agreement that you participated in as proposer or acceptor.
-
#get_billing_adjustment_request(params = {}) ⇒ Types::GetBillingAdjustmentRequestOutput
Retrieves detailed information about a specific billing adjustment request.
-
#list_agreement_cancellation_requests(params = {}) ⇒ Types::ListAgreementCancellationRequestsOutput
Lists agreement cancellation requests available to you as a seller or buyer.
-
#list_agreement_charges(params = {}) ⇒ Types::ListAgreementChargesOutput
Allows acceptors to view charges and purchase orders that are associated with an agreement.
-
#list_agreement_invoice_line_items(params = {}) ⇒ Types::ListAgreementInvoiceLineItemsOutput
Allows sellers (proposers) to retrieve aggregated billing data from AWS Marketplace agreements using flexible grouping.
-
#list_agreement_payment_requests(params = {}) ⇒ Types::ListAgreementPaymentRequestsOutput
Lists payment requests available to you as a seller or buyer.
-
#list_billing_adjustment_requests(params = {}) ⇒ Types::ListBillingAdjustmentRequestsOutput
Lists billing adjustment requests for a specific agreement.
-
#reject_agreement_cancellation_request(params = {}) ⇒ Types::RejectAgreementCancellationRequestOutput
Allows buyers (acceptors) to reject a cancellation request that is in
PENDING_APPROVALstatus. -
#reject_agreement_payment_request(params = {}) ⇒ Types::RejectAgreementPaymentRequestOutput
Allows buyers (acceptors) to reject a payment request that is in
PENDING_APPROVALstatus. -
#search_agreements(params = {}) ⇒ Types::SearchAgreementsOutput
Searches across all agreements that a proposer or an acceptor has in AWS Marketplace.
-
#send_agreement_cancellation_request(params = {}) ⇒ Types::SendAgreementCancellationRequestOutput
Allows sellers (proposers) to submit a cancellation request for an active agreement.
-
#send_agreement_payment_request(params = {}) ⇒ Types::SendAgreementPaymentRequestOutput
Allows sellers (proposers) to submit a payment request to buyers (acceptors) for a specific charge amount for an agreement that includes a
VariablePaymentTerm. -
#update_purchase_orders(params = {}) ⇒ Struct
Allows acceptors to associate purchase orders with agreement charges after an agreement is created.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-marketplaceagreement/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2519 2520 2521 |
# File 'lib/aws-sdk-marketplaceagreement/client.rb', line 2519 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2522 2523 2524 |
# File 'lib/aws-sdk-marketplaceagreement/client.rb', line 2522 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_agreement_cancellation_request(params = {}) ⇒ Types::AcceptAgreementCancellationRequestOutput
Allows buyers (acceptors) to accept a cancellation request that is in
PENDING_APPROVAL status. Once accepted, the cancellation request
transitions to APPROVED status and the agreement cancellation will
be processed.
PENDING_APPROVAL status can be
accepted. A ConflictException is thrown if the cancellation request
is in any other status.
93 |
# File 'sig/client.rbs', line 93
def accept_agreement_cancellation_request: (
|
#accept_agreement_payment_request(params = {}) ⇒ Types::AcceptAgreementPaymentRequestOutput
Allows buyers (acceptors) to accept a payment request that is in
PENDING_APPROVAL status. Once accepted, the payment request
transitions to APPROVED status and the charge will be processed.
Buyers can optionally provide a purchase order reference for their
internal tracking.
PENDING_APPROVAL status can be accepted. A
ConflictException is thrown if the payment request is in any other
status.
112 |
# File 'sig/client.rbs', line 112
def accept_agreement_payment_request: (
|
#accept_agreement_request(params = {}) ⇒ Types::AcceptAgreementRequestOutput
Accepts an agreement request to finalize the agreement. The acceptor can optionally provide purchase orders to associate with the agreement charges.
124 |
# File 'sig/client.rbs', line 124
def accept_agreement_request: (
|
#batch_create_billing_adjustment_request(params = {}) ⇒ Types::BatchCreateBillingAdjustmentRequestOutput
Allows sellers (proposers) to submit billing adjustment requests for one or more invoices within an agreement. Each entry in the batch specifies an invoice and the adjustment amount. The operation returns successfully created adjustment request IDs and any errors for entries that failed to process.
clientToken for idempotency.
143 |
# File 'sig/client.rbs', line 143
def batch_create_billing_adjustment_request: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2492 2493 2494 2495 2496 2497 2498 2499 2500 2501 2502 2503 2504 2505 2506 2507 2508 |
# File 'lib/aws-sdk-marketplaceagreement/client.rb', line 2492 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MarketplaceAgreement') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-marketplaceagreement' context[:gem_version] = '1.42.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_agreement(params = {}) ⇒ Struct
Allows an acceptor to cancel an active agreement. Not all agreements are eligible for cancellation. Use the error response to determine why a cancellation request was rejected.
162 |
# File 'sig/client.rbs', line 162
def cancel_agreement: (
|
#cancel_agreement_cancellation_request(params = {}) ⇒ Types::CancelAgreementCancellationRequestOutput
Allows sellers (proposers) to withdraw an existing agreement
cancellation request that is in a pending state. Once cancelled, the
cancellation request transitions to CANCELLED status and can no
longer be approved or rejected by the buyer.
PENDING_APPROVAL status can be
cancelled. A ConflictException is thrown if the cancellation request
is in any other status.
179 |
# File 'sig/client.rbs', line 179
def cancel_agreement_cancellation_request: (
|
#cancel_agreement_payment_request(params = {}) ⇒ Types::CancelAgreementPaymentRequestOutput
Allows sellers (proposers) to cancel a payment request that is in
PENDING_APPROVAL status. Once cancelled, the payment request
transitions to CANCELLED status and can no longer be accepted or
rejected by the buyer.
PENDING_APPROVAL status can be cancelled. A
ConflictException is thrown if the payment request is in any other
status.
199 |
# File 'sig/client.rbs', line 199
def cancel_agreement_payment_request: (
|
#create_agreement_request(params = {}) ⇒ Types::CreateAgreementRequestOutput
Creates an agreement request that acts as a quote for the terms you
want to accept. The agreement request captures the requested terms,
calculates charges, and returns a summary. Use
AcceptAgreementRequest with the returned agreementRequestId to
finalize the agreement.
211 |
# File 'sig/client.rbs', line 211
def create_agreement_request: (
|
#describe_agreement(params = {}) ⇒ Types::DescribeAgreementOutput
Provides details about an agreement, such as the proposer, acceptor, start date, and end date.
259 |
# File 'sig/client.rbs', line 259
def describe_agreement: (
|
#get_agreement_cancellation_request(params = {}) ⇒ Types::GetAgreementCancellationRequestOutput
Retrieves detailed information about a specific agreement cancellation request. Both sellers (proposers) and buyers (acceptors) can use this operation to view cancellation requests associated with their agreements.
276 |
# File 'sig/client.rbs', line 276
def get_agreement_cancellation_request: (
|
#get_agreement_entitlements(params = {}) ⇒ Types::GetAgreementEntitlementsOutput
Obtains details about the entitlements of an agreement.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
288 |
# File 'sig/client.rbs', line 288
def get_agreement_entitlements: (
|
#get_agreement_payment_request(params = {}) ⇒ Types::GetAgreementPaymentRequestOutput
Retrieves detailed information about a specific payment request. Both sellers (proposers) and buyers (acceptors) can use this operation to view payment requests associated with their agreements. The response includes the current status, charge details, timestamps, and the charge ID if the request has been approved.
ResourceNotFoundException is returned if the
payment request does not exist.
310 |
# File 'sig/client.rbs', line 310
def get_agreement_payment_request: (
|
#get_agreement_terms(params = {}) ⇒ Types::GetAgreementTermsOutput
Obtains details about the terms in an agreement that you participated in as proposer or acceptor.
The details include:
-
TermType– The type of term, such asLegalTerm,RenewalTerm, orConfigurableUpfrontPricingTerm. -
TermID– The ID of the particular term, which is common between offer and agreement. -
TermPayload– The key information contained in the term, such as the EULA forLegalTermor pricing and dimensions for various pricing terms, such asConfigurableUpfrontPricingTermorUsageBasedPricingTerm. ^ -
Configuration– The buyer/acceptor's selection at the time of agreement creation, such as the number of units purchased for a dimension or setting theEnableAutoRenewflag.
^
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
322 |
# File 'sig/client.rbs', line 322
def get_agreement_terms: (
|
#get_billing_adjustment_request(params = {}) ⇒ Types::GetBillingAdjustmentRequestOutput
Retrieves detailed information about a specific billing adjustment request. Sellers (proposers) can use this operation to view the status and details of a billing adjustment request they submitted.
344 |
# File 'sig/client.rbs', line 344
def get_billing_adjustment_request: (
|
#list_agreement_cancellation_requests(params = {}) ⇒ Types::ListAgreementCancellationRequestsOutput
Lists agreement cancellation requests available to you as a seller or buyer. Both sellers (proposers) and buyers (acceptors) can use this operation to find cancellation requests by specifying their party type and applying optional filters.
PartyType is a required parameter. A ValidationException is
returned if PartyType is not provided.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
356 |
# File 'sig/client.rbs', line 356
def list_agreement_cancellation_requests: (
|
#list_agreement_charges(params = {}) ⇒ Types::ListAgreementChargesOutput
Allows acceptors to view charges and purchase orders that are associated with an agreement. The response includes details about all charges regardless of whether a purchase order is linked to each charge.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
373 |
# File 'sig/client.rbs', line 373
def list_agreement_charges: (
|
#list_agreement_invoice_line_items(params = {}) ⇒ Types::ListAgreementInvoiceLineItemsOutput
Allows sellers (proposers) to retrieve aggregated billing data from AWS Marketplace agreements using flexible grouping. Supports invoice-level aggregation with filtering by billing period, invoice type, and issued date.
groupBy parameter is required and supports only INVOICE_ID as
a value. The agreementId parameter is required.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
388 |
# File 'sig/client.rbs', line 388
def list_agreement_invoice_line_items: (
|
#list_agreement_payment_requests(params = {}) ⇒ Types::ListAgreementPaymentRequestsOutput
Lists payment requests available to you as a seller or buyer. Both sellers (proposers) and buyers (acceptors) can use this operation to find payment requests by specifying their party type and applying optional parameters.
PartyType is a required parameter. A ValidationException is
returned if PartyType is not provided. Pagination is supported
through maxResults (1-50, default 50) and nextToken parameters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
410 |
# File 'sig/client.rbs', line 410
def list_agreement_payment_requests: (
|
#list_billing_adjustment_requests(params = {}) ⇒ Types::ListBillingAdjustmentRequestsOutput
Lists billing adjustment requests for a specific agreement. Sellers (proposers) can use this operation to view all billing adjustment requests associated with an agreement.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
427 |
# File 'sig/client.rbs', line 427
def list_billing_adjustment_requests: (
|
#reject_agreement_cancellation_request(params = {}) ⇒ Types::RejectAgreementCancellationRequestOutput
Allows buyers (acceptors) to reject a cancellation request that is in
PENDING_APPROVAL status. Once rejected, the cancellation request
transitions to REJECTED status and the agreement remains active.
Buyers must provide a reason for the rejection.
PENDING_APPROVAL status can be
rejected. A ConflictException is thrown if the cancellation request
is in any other status.
451 |
# File 'sig/client.rbs', line 451
def reject_agreement_cancellation_request: (
|
#reject_agreement_payment_request(params = {}) ⇒ Types::RejectAgreementPaymentRequestOutput
Allows buyers (acceptors) to reject a payment request that is in
PENDING_APPROVAL status. Once rejected, the payment request
transitions to REJECTED status and cannot be accepted. Buyers can
optionally provide a reason for the rejection.
PENDING_APPROVAL status can be rejected. A
ConflictException is thrown if the payment request is in any other
status.
472 |
# File 'sig/client.rbs', line 472
def reject_agreement_payment_request: (
|
#search_agreements(params = {}) ⇒ Types::SearchAgreementsOutput
Searches across all agreements that a proposer or an acceptor has in AWS Marketplace. The search returns a list of agreements with basic agreement information.
The following filter combinations are supported when the PartyType
is Proposer:
-
AgreementType -
AgreementType+EndTime -
AgreementType+ResourceType -
AgreementType+ResourceType+EndTime -
AgreementType+ResourceType+Status -
AgreementType+ResourceType+Status+EndTime -
AgreementType+ResourceIdentifier -
AgreementType+ResourceIdentifier+EndTime -
AgreementType+ResourceIdentifier+Status -
AgreementType+ResourceIdentifier+Status+EndTime -
AgreementType+AcceptorAccountId -
AgreementType+AcceptorAccountId+EndTime -
AgreementType+AcceptorAccountId+Status -
AgreementType+AcceptorAccountId+Status+EndTime -
AgreementType+AcceptorAccountId+OfferId -
AgreementType+AcceptorAccountId+OfferId+Status -
AgreementType+AcceptorAccountId+OfferId+EndTime -
AgreementType+AcceptorAccountId+OfferId+Status+EndTime -
AgreementType+AcceptorAccountId+ResourceIdentifier -
AgreementType+AcceptorAccountId+ResourceIdentifier+Status -
AgreementType+AcceptorAccountId+ResourceIdentifier+EndTime -
AgreementType+AcceptorAccountId+ResourceIdentifier+Status+EndTime -
AgreementType+AcceptorAccountId+ResourceType -
AgreementType+AcceptorAccountId+ResourceType+EndTime -
AgreementType+AcceptorAccountId+ResourceType+Status -
AgreementType+AcceptorAccountId+ResourceType+Status+EndTime -
AgreementType+Status -
AgreementType+Status+EndTime -
AgreementType+OfferId -
AgreementType+OfferId+EndTime -
AgreementType+OfferId+Status -
AgreementType+OfferId+Status+EndTime -
AgreementType+OfferSetId -
AgreementType+OfferSetId+EndTime -
AgreementType+OfferSetId+Status -
AgreementType+OfferSetId+Status+EndTime
EndTime, you can use BeforeEndTime and/or
AfterEndTime. Only EndTime is supported for sorting.
The following filter combinations are supported when the PartyType
is Acceptor:
-
AgreementType -
AgreementType+Status -
AgreementType+EndTime -
AgreementType+Status+EndTime -
AgreementType+ResourceIdentifier -
AgreementType+ResourceIdentifier+EndTime -
AgreementType+ResourceIdentifier+Status -
AgreementType+ResourceIdentifier+Status+EndTime -
AgreementType+ResourceType -
AgreementType+ResourceType+EndTime -
AgreementType+OfferId -
AgreementType+OfferId+EndTime -
AgreementType+OfferId+Status -
AgreementType+OfferId+Status+EndTime -
AgreementType+OfferSetId -
AgreementType+OfferSetId+EndTime -
AgreementType+OfferSetId+Status -
AgreementType+OfferSetId+Status+EndTime
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
485 |
# File 'sig/client.rbs', line 485
def search_agreements: (
|
#send_agreement_cancellation_request(params = {}) ⇒ Types::SendAgreementCancellationRequestOutput
Allows sellers (proposers) to submit a cancellation request for an
active agreement. The cancellation request is created in
PENDING_APPROVAL status, at which point the buyer can review it.
513 |
# File 'sig/client.rbs', line 513
def send_agreement_cancellation_request: (
|
#send_agreement_payment_request(params = {}) ⇒ Types::SendAgreementPaymentRequestOutput
Allows sellers (proposers) to submit a payment request to buyers
(acceptors) for a specific charge amount for an agreement that
includes a VariablePaymentTerm. The payment request is created in
PENDING_APPROVAL status, at which point the buyer can accept or
reject it.
VariablePaymentTerm to
support payment requests. The chargeAmount must not exceed the
remaining available balance under the VariablePaymentTerm
maxTotalChargeAmount.
533 |
# File 'sig/client.rbs', line 533
def send_agreement_payment_request: (
|
#update_purchase_orders(params = {}) ⇒ Struct
Allows acceptors to associate purchase orders with agreement charges after an agreement is created.
547 |
# File 'sig/client.rbs', line 547
def update_purchase_orders: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2512 2513 2514 |
# File 'lib/aws-sdk-marketplaceagreement/client.rb', line 2512 def waiter_names [] end |