Module: Aws::MarketplaceAgreement::Types
- Defined in:
- lib/aws-sdk-marketplaceagreement/types.rb
Defined Under Namespace
Classes: AcceptAgreementCancellationRequestInput, AcceptAgreementCancellationRequestOutput, AcceptAgreementPaymentRequestInput, AcceptAgreementPaymentRequestOutput, AcceptAgreementRequestInput, AcceptAgreementRequestOutput, AcceptedTerm, Acceptor, AccessDeniedException, AgreementCancellationRequestSummary, AgreementEntitlement, AgreementInvoiceLineItemGroupSummary, AgreementViewSummary, BatchCreateBillingAdjustmentError, BatchCreateBillingAdjustmentItem, BatchCreateBillingAdjustmentRequestEntry, BatchCreateBillingAdjustmentRequestInput, BatchCreateBillingAdjustmentRequestOutput, BillingAdjustmentSummary, ByolPricingTerm, CancelAgreementCancellationRequestInput, CancelAgreementCancellationRequestOutput, CancelAgreementInput, CancelAgreementOutput, CancelAgreementPaymentRequestInput, CancelAgreementPaymentRequestOutput, Charge, ChargeSummary, ConfigurableUpfrontPricingTerm, ConfigurableUpfrontPricingTermConfiguration, ConfigurableUpfrontRateCardItem, ConflictException, Constraints, CreateAgreementRequestInput, CreateAgreementRequestOutput, DescribeAgreementInput, DescribeAgreementOutput, Dimension, DocumentItem, EstimatedCharges, EstimatedTaxes, ExpectedCharge, Filter, FixedUpfrontPricingTerm, FreeTrialPricingTerm, GetAgreementCancellationRequestInput, GetAgreementCancellationRequestOutput, GetAgreementEntitlementsInput, GetAgreementEntitlementsOutput, GetAgreementPaymentRequestInput, GetAgreementPaymentRequestOutput, GetAgreementTermsInput, GetAgreementTermsOutput, GetBillingAdjustmentRequestInput, GetBillingAdjustmentRequestOutput, GrantItem, InternalServerException, InvoiceBillingPeriod, InvoicingEntity, ItemizedCharge, LegalTerm, ListAgreementCancellationRequestsInput, ListAgreementCancellationRequestsOutput, ListAgreementChargesInput, ListAgreementChargesOutput, ListAgreementInvoiceLineItemsInput, ListAgreementInvoiceLineItemsOutput, ListAgreementPaymentRequestsInput, ListAgreementPaymentRequestsOutput, ListBillingAdjustmentRequestsInput, ListBillingAdjustmentRequestsOutput, PaymentRequestSummary, PaymentScheduleTerm, PricingCurrencyAmount, ProposalSummary, Proposer, PurchaseOrder, RateCardItem, RecurringPaymentTerm, RejectAgreementCancellationRequestInput, RejectAgreementCancellationRequestOutput, RejectAgreementPaymentRequestInput, RejectAgreementPaymentRequestOutput, RenewalTerm, RenewalTermConfiguration, RequestedTerm, RequestedTermConfiguration, Resource, ResourceNotFoundException, ScheduleItem, SearchAgreementsInput, SearchAgreementsOutput, Selector, SendAgreementCancellationRequestInput, SendAgreementCancellationRequestOutput, SendAgreementPaymentRequestInput, SendAgreementPaymentRequestOutput, ServiceQuotaExceededException, Sort, SupportTerm, TaxBreakdownItem, TaxConfiguration, ThrottlingException, UpdatePurchaseOrdersInput, UpdatePurchaseOrdersOutput, UsageBasedPricingTerm, UsageBasedRateCardItem, ValidationException, ValidationExceptionField, ValidityTerm, VariablePaymentTerm, VariablePaymentTermConfiguration
Instance Attribute Summary collapse
-
#byol_pricing_term ⇒ Types::ByolPricingTerm
Enables you and your customers to move your existing agreements to AWS Marketplace.
-
#configurable_upfront_pricing_term ⇒ Types::ConfigurableUpfrontPricingTerm
Defines a prepaid payment model that allows buyers to configure the entitlements they want to purchase and the duration.
-
#configurable_upfront_pricing_term_configuration ⇒ Types::ConfigurableUpfrontPricingTermConfiguration
Defines a prepaid payment model that allows buyers to configure the entitlements they want to purchase and the duration.
-
#fixed_upfront_pricing_term ⇒ Types::FixedUpfrontPricingTerm
Defines a pre-paid pricing model where the customers are charged a fixed upfront amount.
-
#free_trial_pricing_term ⇒ Types::FreeTrialPricingTerm
Defines a short-term free pricing model where the buyers aren’t charged anything within a specified limit.
-
#legal_term ⇒ Types::LegalTerm
Defines the list of text agreements proposed to the acceptors.
-
#payment_schedule_term ⇒ Types::PaymentScheduleTerm
Defines an installment-based pricing model where customers are charged a fixed price on different dates during the agreement validity period.
-
#recurring_payment_term ⇒ Types::RecurringPaymentTerm
Defines a pricing model where customers are charged a fixed recurring price at the end of each billing period.
-
#renewal_term ⇒ Types::RenewalTerm
Defines that on graceful expiration of the agreement (when the agreement ends on its pre-defined end date), a new agreement will be created using the accepted terms on the existing agreement.
-
#renewal_term_configuration ⇒ Types::RenewalTermConfiguration
Additional parameters specified by the acceptor while accepting the term.
-
#support_term ⇒ Types::SupportTerm
Defines the customer support available for the acceptors when they purchase the software.
-
#usage_based_pricing_term ⇒ Types::UsageBasedPricingTerm
Defines a usage-based pricing model (typically, pay-as-you-go pricing), where the customers are charged based on product usage.
-
#validity_term ⇒ Types::ValidityTerm
Defines the conditions that will keep an agreement created from this offer valid.
-
#variable_payment_term ⇒ Types::VariablePaymentTerm
Defines a payment model where sellers can submit variable payment requests up to a maximum charge amount, with configurable approval strategies and expiration timelines.
-
#variable_payment_term_configuration ⇒ Types::VariablePaymentTermConfiguration
Additional parameters specified by the acceptor while accepting the variable payment term.
Instance Attribute Details
#byol_pricing_term ⇒ Types::ByolPricingTerm
Enables you and your customers to move your existing agreements to AWS Marketplace. The customer won’t be charged for product usage in AWS Marketplace because they already paid for the product outside of AWS Marketplace.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#configurable_upfront_pricing_term ⇒ Types::ConfigurableUpfrontPricingTerm
Defines a prepaid payment model that allows buyers to configure the entitlements they want to purchase and the duration.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#configurable_upfront_pricing_term_configuration ⇒ Types::ConfigurableUpfrontPricingTermConfiguration
Defines a prepaid payment model that allows buyers to configure the entitlements they want to purchase and the duration.
2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 2924 class RequestedTermConfiguration < Struct.new( :configurable_upfront_pricing_term_configuration, :renewal_term_configuration, :variable_payment_term_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ConfigurableUpfrontPricingTermConfiguration < RequestedTermConfiguration; end class RenewalTermConfiguration < RequestedTermConfiguration; end class VariablePaymentTermConfiguration < RequestedTermConfiguration; end class Unknown < RequestedTermConfiguration; end end |
#fixed_upfront_pricing_term ⇒ Types::FixedUpfrontPricingTerm
Defines a pre-paid pricing model where the customers are charged a fixed upfront amount.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#free_trial_pricing_term ⇒ Types::FreeTrialPricingTerm
Defines a short-term free pricing model where the buyers aren’t charged anything within a specified limit.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#legal_term ⇒ Types::LegalTerm
Defines the list of text agreements proposed to the acceptors. An example is the end user license agreement (EULA).
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#payment_schedule_term ⇒ Types::PaymentScheduleTerm
Defines an installment-based pricing model where customers are charged a fixed price on different dates during the agreement validity period. This is used most commonly for flexible payment schedule pricing.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#recurring_payment_term ⇒ Types::RecurringPaymentTerm
Defines a pricing model where customers are charged a fixed recurring price at the end of each billing period.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#renewal_term ⇒ Types::RenewalTerm
Defines that on graceful expiration of the agreement (when the agreement ends on its pre-defined end date), a new agreement will be created using the accepted terms on the existing agreement. In other words, the agreement will be renewed. Presence of ‘RenewalTerm` in the offer document means that auto-renewal is allowed. Buyers will have the option to accept or decline auto-renewal at the offer acceptance/agreement creation. Buyers can also change this flag from `True` to `False` or `False` to `True` at anytime during the agreement’s lifecycle.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#renewal_term_configuration ⇒ Types::RenewalTermConfiguration
Additional parameters specified by the acceptor while accepting the term.
2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 2924 class RequestedTermConfiguration < Struct.new( :configurable_upfront_pricing_term_configuration, :renewal_term_configuration, :variable_payment_term_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ConfigurableUpfrontPricingTermConfiguration < RequestedTermConfiguration; end class RenewalTermConfiguration < RequestedTermConfiguration; end class VariablePaymentTermConfiguration < RequestedTermConfiguration; end class Unknown < RequestedTermConfiguration; end end |
#support_term ⇒ Types::SupportTerm
Defines the customer support available for the acceptors when they purchase the software.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#usage_based_pricing_term ⇒ Types::UsageBasedPricingTerm
Defines a usage-based pricing model (typically, pay-as-you-go pricing), where the customers are charged based on product usage.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#validity_term ⇒ Types::ValidityTerm
Defines the conditions that will keep an agreement created from this offer valid.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#variable_payment_term ⇒ Types::VariablePaymentTerm
Defines a payment model where sellers can submit variable payment requests up to a maximum charge amount, with configurable approval strategies and expiration timelines.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 264 class AcceptedTerm < Struct.new( :legal_term, :support_term, :renewal_term, :usage_based_pricing_term, :configurable_upfront_pricing_term, :byol_pricing_term, :recurring_payment_term, :validity_term, :payment_schedule_term, :free_trial_pricing_term, :fixed_upfront_pricing_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LegalTerm < AcceptedTerm; end class SupportTerm < AcceptedTerm; end class RenewalTerm < AcceptedTerm; end class UsageBasedPricingTerm < AcceptedTerm; end class ConfigurableUpfrontPricingTerm < AcceptedTerm; end class ByolPricingTerm < AcceptedTerm; end class RecurringPaymentTerm < AcceptedTerm; end class ValidityTerm < AcceptedTerm; end class PaymentScheduleTerm < AcceptedTerm; end class FreeTrialPricingTerm < AcceptedTerm; end class FixedUpfrontPricingTerm < AcceptedTerm; end class VariablePaymentTerm < AcceptedTerm; end class Unknown < AcceptedTerm; end end |
#variable_payment_term_configuration ⇒ Types::VariablePaymentTermConfiguration
Additional parameters specified by the acceptor while accepting the variable payment term.
2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 |
# File 'lib/aws-sdk-marketplaceagreement/types.rb', line 2924 class RequestedTermConfiguration < Struct.new( :configurable_upfront_pricing_term_configuration, :renewal_term_configuration, :variable_payment_term_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ConfigurableUpfrontPricingTermConfiguration < RequestedTermConfiguration; end class RenewalTermConfiguration < RequestedTermConfiguration; end class VariablePaymentTermConfiguration < RequestedTermConfiguration; end class Unknown < RequestedTermConfiguration; end end |